@@ -57,6 +57,9 @@
 #define DBUS_API_SUBJECT_TO_CHANGE
 #include <dbus/dbus.h>
 
+#include "pidinfo.h"
+#include "pid_ui.h"
+
 #define _(String) dgettext (PACKAGE, String)
 
 #define HILDON_STATUS_BAR_BORDER_WIDTH 20
@@ -86,6 +89,8 @@
 #define CPU_MID 60
 #define CPU_HIGH 90
 
+
+
 typedef struct
 {
     HildonStatusBarItem *item;
@@ -105,6 +110,7 @@ typedef struct
     GtkWidget *menu_separator;
     GtkWidget *menu_screenshot;
     GtkWidget *menu_delayed_screenshot;
+    GtkWidget *menu_list_processes;
     GtkWidget *menu_settings;
     /* Flags */
     gboolean in_area;
@@ -283,6 +289,7 @@ pos_menu(GtkMenu *menu, gint *x, gint *y,
     *y = HILDON_STATUS_BAR_MENU_Y_POS;
 }
 
+
 static void
 make_screenshot(void)
 {
@@ -362,14 +369,12 @@ activate_delayed_screenshot_item(GtkMenuItem *item, gpointer data)
 static void
 activate_settings_item(GtkMenuItem *item, gpointer data)
 {
-	#define LOAD_DIALOG_ACCEPT 1
-	#define LOAD_DIALOG_CANCEL 2
         GtkWidget *dialog;
         GtkWidget *button_accept, *button_cancel;
         GtkWidget *vbox, *hboxtop, *hboxbottom;
         GtkWidget *labeldelay, *labelfilename;
         GtkWidget *sb_seconds;
-	GtkWidget *entry_filename;
+        GtkWidget *entry_filename;
         gint result;
 
         dialog = gtk_dialog_new_with_buttons ("Screenshot settings",
@@ -399,7 +404,7 @@ activate_settings_item(GtkMenuItem *item, gpointer data)
                             TRUE,
                             TRUE,
                             5);
-        sb_seconds = gtk_spin_button_new_with_range ( 0, 9999999, 1);
+        sb_seconds = gtk_spin_button_new_with_range ( 0, 9999999, 1);	
         gtk_box_pack_start (GTK_BOX(hboxtop),
                             sb_seconds,
                             TRUE,
@@ -428,9 +433,7 @@ activate_settings_item(GtkMenuItem *item, gpointer data)
                             TRUE,
                             5);
 
-        if (ossohelp_dialog_help_enable(GTK_DIALOG(dialog), "Settings_LoadApplet_Main", info->osso_context) == FALSE)
-                fprintf(stderr, "\tNo such help topic\n");
-
+        ossohelp_dialog_help_enable(GTK_DIALOG(dialog), "Settings_LoadApplet_Main", info->osso_context);
         gtk_widget_show_all(dialog);
         result = gtk_dialog_run (GTK_DIALOG (dialog));
         switch (result)
@@ -459,7 +462,6 @@ deactivate_menu_cb(GtkMenuShell *menushell, gpointer data)
 				 FALSE);
 }
 
-
 static void 
 load_icon_pressed(GtkWidget *widget, gpointer data)
 {
@@ -472,21 +474,33 @@ load_icon_pressed(GtkWidget *widget, gpointer data)
         gtk_menu_shell_append(GTK_MENU_SHELL(info->menu),
 			info->menu_screenshot);
         g_signal_connect(G_OBJECT(info->menu_screenshot),
-	                "activate",
-			G_CALLBACK(activate_screenshot_item),
-			data);
-	/* And delayed screenshot */
+                         "activate",
+                         G_CALLBACK(activate_screenshot_item),
+                         data);
+        /* And delayed screenshot */
         info->menu_delayed_screenshot = gtk_menu_item_new_with_label("Take delayed screenshot");
         gtk_menu_shell_append(GTK_MENU_SHELL(info->menu),
                         info->menu_delayed_screenshot);
         g_signal_connect(G_OBJECT(info->menu_delayed_screenshot),
+                         "activate",
+                         G_CALLBACK(activate_delayed_screenshot_item),
+                         data);
+        /* Separator */
+        info->menu_separator = gtk_separator_menu_item_new();
+        gtk_menu_shell_append(GTK_MENU_SHELL(info->menu),
+                         info->menu_separator);
+        /* List processes */
+        info->menu_list_processes = gtk_menu_item_new_with_label("List processes");
+        gtk_menu_shell_append(GTK_MENU_SHELL(info->menu),
+                        info->menu_list_processes);
+        g_signal_connect(G_OBJECT(info->menu_list_processes),
                         "activate",
-                        G_CALLBACK(activate_delayed_screenshot_item),
+                        G_CALLBACK(activate_list_processes_item),
                         data);
         /* Separator */
         info->menu_separator = gtk_separator_menu_item_new();
         gtk_menu_shell_append(GTK_MENU_SHELL(info->menu),
-                        info->menu_separator);
+                         info->menu_separator);
         /* Settings */
         info->menu_settings = gtk_menu_item_new_with_label("Settings");
         gtk_menu_shell_append(GTK_MENU_SHELL(info->menu),
@@ -512,9 +526,9 @@ load_icon_pressed(GtkWidget *widget, gpointer data)
                          info);
 
         g_signal_connect(G_OBJECT(info->menu),
-			 "deactivate",
-			 G_CALLBACK(deactivate_menu_cb),
-			 info);
+                         "deactivate",
+                         G_CALLBACK(deactivate_menu_cb),
+                         info);
 
         gtk_widget_show_all(info->menu);
     }
@@ -696,7 +710,6 @@ check_load_cpu (gpointer data)
     guchar current_cpu_level;
     guchar current_mem_level;
     gboolean currently_is_swap_used;
-	
    
     current_cpu_level = check_cpu(); 
     current_mem_level = check_mem();
@@ -712,7 +725,7 @@ check_load_cpu (gpointer data)
         gtk_image_set_from_pixbuf(GTK_IMAGE(info->icon), info->pixbuf_current);
         info->last_mem_level = current_mem_level;
         info->last_cpu_level = current_cpu_level;
-	info->is_swap_used = currently_is_swap_used; 
+        info->is_swap_used = currently_is_swap_used; 
     }
 
     return TRUE;  
@@ -741,6 +754,7 @@ hildon_im_hw_cb(osso_hw_state_t* state, gpointer data)
         /* Go sleep */
         im_inactive = TRUE;
         g_source_remove(info->timeout_id);
+        info->timeout_id = 0;
     }
 }
 
@@ -839,19 +853,33 @@ load_entry(HildonStatusBarPluginFn_st *fn)
     fn->get_priority = load_get_priority;
 }
 
+/* 
+ * This function is a hack to get this working in Sardine :( 
+ * Status Bar looks for load_entry in IT-2006 and for LoadApplet_entry in Sardine :(
+ */
+void
+LoadApplet_entry(HildonStatusBarPluginFn_st *fn)
+{
+	load_entry(fn);
+}
+
 void 
 load_destroy(void *data) 
 {
-    g_object_unref(info->pixbuf_frame);
-    g_object_unref(info->pixbuf_cpu);
-    g_object_unref(info->pixbuf_mem);
-    g_object_unref(info->pixbuf_swap);
-    g_object_unref(info->pixbuf_bar2);
-    g_object_unref(info->pixbuf_bar3);
-    g_object_unref(info->pixbuf_bar4);
-    g_object_unref(info->pixbuf_current);
+    if (info->timeout_id)
+        g_source_remove (info->timeout_id);
 
-    g_free(data);
+    g_object_unref (info->pixbuf_frame);
+    g_object_unref (info->pixbuf_cpu);
+    g_object_unref (info->pixbuf_mem);
+    g_object_unref (info->pixbuf_swap);
+    g_object_unref (info->pixbuf_bar2);
+    g_object_unref (info->pixbuf_bar3);
+    g_object_unref (info->pixbuf_bar4);
+    g_object_unref (info->pixbuf_current);
+
+    g_free (info);
+    /* "data" is freed by Status Bar! */
 }
 
 /* if value1 == 1, the plugin is created, 
